@@ -41,7 +41,7 @@ from xml.sax import saxutils
 from xml.sax import handler
 from xml.sax.handler import feature_namespaces
 
-VERSION = "1.1.7"
+VERSION = "1.1.7-3"
 
 try:
     import hildon
@@ -904,6 +904,8 @@ class Main:
         self.recordChanged = 0
         self.ClearButtons()
         self.ActivateFields()
+        pwdBtn = self.wTree.get_widget("main_genpwd_btn")
+        pwdBtn.set_sensitive( True )
         self.curRecord = recordNum
         
     def OnSelectRow( self, editing, user_param ) :
